<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="he_IL" sourcelanguage="en">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../src/tiled/aboutdialog.ui" line="+14"/>
        <source>About Tiled</source>
        <translation>על Tiled</translation>
    </message>
    <message>
        <location line="+96"/>
        <source>OK</source>
        <translation>אישור</translation>
    </message>
    <message>
        <location filename="../src/tiled/aboutdialog.cpp" line="+32"/>
        <source>&lt;p align=&quot;center&quot;&gt;&lt;font size=&quot;+2&quot;&gt;&lt;b&gt;Tiled Map Editor&lt;/b&gt;&lt;/font&gt;&lt;br&gt;&lt;i&gt;Version %1&lt;/i&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot;&gt;Copyright 2008-2010 Thorbj&amp;oslash;rn Lindeijer&lt;br&gt;(see the AUTHORS file for a full list of contributors)&lt;/p&gt;
&lt;p align=&quot;center&quot;&gt;You may modify and redistribute this program under the terms of the GPL (version 2 or later). A copy of the GPL is contained in the &apos;COPYING&apos; file distributed with Tiled.&lt;/p&gt;
&lt;p align=&quot;center&quot;&gt;&lt;a href=&quot;http://www.mapeditor.org/&quot;&gt;http://www.mapeditor.org/&lt;/a&gt;&lt;/p&gt;
</source>
        <translation>&lt;p align=&quot;center&quot;&gt;&lt;font size=&quot;+2&quot;&gt;&lt;b&gt;עורך המפות Tiled&lt;/b&gt;&lt;/font&gt;&lt;br&gt;&lt;i&gt;גרסא %1&lt;/i&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot;&gt;זכויות יוצרים שמורות ל 2008-2010 Thorbj&amp;oslash;rn Lindeijer&lt;br&gt;(ראה קובץ AUTHORS לרשימה מלאה של תורמים)&lt;/p&gt;
&lt;p align=&quot;center&quot;&gt;הנך מורשה להפיץ מחדש תוכנה זאת תחת חוקי רשיון GPL (ראה קובץ מצורף)&lt;/p&gt;
&lt;p align=&quot;center&quot;&gt;&lt;a href=&quot;http://www.mapeditor.org/&quot;&gt;http://www.mapeditor.org/&lt;/a&gt;&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>AutoMapper</name>
    <message>
        <source>No set layer found!</source>
        <translation type="obsolete">לא נמצא מקור שכבה!</translation>
    </message>
    <message>
        <source>No ruleRegions layer found!</source>
        <translation type="obsolete">לא נמצאו חוקי אזור שכבה!</translation>
    </message>
    <message>
        <source>No set layers found!</source>
        <translation type="obsolete">לא נמצאו מקורות שכבות!</translation>
    </message>
    <message>
        <source>No ruleSet layer found!</source>
        <translation type="obsolete">לא נמצאה שכבת סט חוקים!</translation>
    </message>
    <message>
        <source>Multiple layers %1 found!</source>
        <translation type="obsolete">מספר שכבות %1 נמצאו!</translation>
    </message>
    <message>
        <source>Tile</source>
        <translation type="obsolete">משבצת</translation>
    </message>
</context>
<context>
    <name>AutomaticMapping</name>
    <message>
        <source>AutoMap Error</source>
        <translation type="obsolete">שגיאה במיפוי אוטומתי</translation>
    </message>
    <message>
        <source>No rules file found at:
%1</source>
        <translation type="obsolete">לא נמצאו חוקים ב:
%1</translation>
    </message>
    <message>
        <source>Error opening rules file:
%1</source>
        <translation type="obsolete">בעיה בפתיחת קובץ חוקים:
%1</translation>
    </message>
    <message>
        <source>AutoMap Warning</source>
        <translation type="obsolete">אזהרת מיפוי אוטומתי</translation>
    </message>
    <message>
        <source>file not found:
%1</source>
        <translation type="obsolete">קובץ לא נמצא:
%1</translation>
    </message>
    <message>
        <source>Error Opening Rules Map</source>
        <translation type="obsolete">שגיאה בפתיחת מפת חוקים</translation>
    </message>
</context>
<context>
    <name>CommandDialog</name>
    <message>
        <location filename="../src/tiled/commanddialog.ui" line="+14"/>
        <source>Properties</source>
        <translation>ערכים</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>&amp;Save map before executing</source>
        <translation>&amp;שמור מפה לפני ביצוע</translation>
    </message>
    <message>
        <source>Save map before executing</source>
        <translation type="obsolete">שמירת מפה לפני ביצוע</translation>
    </message>
</context>
<context>
    <name>Droidcraft::DroidcraftPlugin</name>
    <message>
        <location filename="../src/plugins/droidcraft/droidcraftplugin.cpp" line="+56"/>
        <source>This is not a valid Droidcraft map file!</source>
        <translation>זהו אינו קובץ מפת Droidcraft תקין!</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>The map needs to have exactly one tile layer!</source>
        <translation>חייב להיות למפה בדיוק שכבת משבצות אחת!</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>The layer must have a size of 48 x 48 tiles!</source>
        <translation>המפה חייבת להיות בגודל של 48x48 משבצות!</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Could not open file for writing.</source>
        <translation>לא ניתן לפתוח את הקובץ לכתיבה.</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Droidcraft map files (*.dat)</source>
        <translation>קובץ מפת Droidcraft (*.dat(</translation>
    </message>
</context>
<context>
    <name>Lua::LuaPlugin</name>
    <message>
        <location filename="../src/plugins/lua/luaplugin.cpp" line="+46"/>
        <source>Could not open file for writing.</source>
        <translation>לא היה ניתן לפתוח את הקובץ לכתיבה.</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Lua files (*.lua)</source>
        <translation>קבצי Lua (*.lua)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/tiled/mainwindow.ui" line="+17"/>
        <source>Tiled</source>
        <translation>Tiled</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;File</source>
        <translation>&amp;קובץ</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Recent Files</source>
        <translation>&amp;קבצים אחרונים</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Edit</source>
        <translation>&amp;ערוך</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Help</source>
        <translation>&amp;עזרה</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Map</source>
        <translation>&amp;מפה</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;View</source>
        <translation>&amp;תצוגה</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Main Toolbar</source>
        <translation>סרגל כלים ראשי</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Open...</source>
        <translation>&amp;פתח...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Save</source>
        <translation>&amp;שמור</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Quit</source>
        <translation>&amp;יציאה</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>&amp;Copy</source>
        <translation>ה&amp;עתק</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>&amp;Paste</source>
        <translation>ה&amp;דבק</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;About Tiled</source>
        <translation>על &amp;Tiled</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>About Qt</source>
        <translation>על Qt</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>&amp;Resize Map...</source>
        <translation>&amp;שנה את גודל המפה...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Map &amp;Properties...</source>
        <translation>הגדרות ה&amp;מפה...</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>AutoMap</source>
        <translation>מיפוי אוטומתי</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Show &amp;Grid</source>
        <translation>הצג &amp;לוח</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+G</source>
        <translation></translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Save &amp;As...</source>
        <translation>שמור בש&amp;ם...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;New...</source>
        <translation>&amp;חדש...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>New &amp;Tileset...</source>
        <translation>סט מ&amp;שבצות חדש...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Close</source>
        <translation>&amp;סגור</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Zoom In</source>
        <translation>הגדל</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Zoom Out</source>
        <translation>הקטן</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Normal Size</source>
        <translation>גודל רגיל</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+0</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Save As &amp;Image...</source>
        <translation>שמור בתור &amp;תמונה...</translation>
    </message>
    <message>
        <source>Save As Image...</source>
        <translation type="obsolete">שמור בתור תמונה...</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Cu&amp;t</source>
        <translation>&amp;גזור</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Offset Map...</source>
        <translation>שנה את &amp;תחילת המפה...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Offsets everything in a layer</source>
        <translation>שנה את תחילת השכבה</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Pre&amp;ferences...</source>
        <translation>ה&amp;עדפות...</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Clear Recent Files</source>
        <translation>נקה קבצים אחרונים</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Export As...</source>
        <translation>י&amp;צא בתור...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+E</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Add External Tileset...</source>
        <translation>&amp;הוסף סט משבצות חיצוני...</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Snap to Grid</source>
        <translation>ה&amp;צמד ללוח</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>C&amp;lose All</source>
        <translation>סגור ה&amp;כל</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+Shift+W</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>MapReader</name>
    <message>
        <location filename="../src/libtiled/mapreader.cpp" line="+130"/>
        <source>Not a map file.</source>
        <translation>לא קובץ מפה.</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Not a tileset file.</source>
        <translation>לא קובץ של סט משבצות.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>%3

Line %1, column %2</source>
        <translation>%3 שורה %1, תור %2</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>File not found: %1</source>
        <translation>קובץ לא נמצא: %1</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Unable to read file: %1</source>
        <translation>לא היה ניתן לקרוא את הקובץ: %1</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>Unsupported map orientation: &quot;%1&quot;</source>
        <translation>אוריאנטציה לא נתמכת: &quot;%1&quot;</translation>
    </message>
    <message>
        <location line="+56"/>
        <source>Invalid tileset parameters for tileset &apos;%1&apos;</source>
        <translation>פרמטרים לא חוקים לסט המשבצות &apos;%1&apos;</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Error while loading tileset &apos;%1&apos;: %2</source>
        <translation>בעיה בטעינת סט המשבצות &apos;%1&apos;: %2</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Invalid tile ID: %1</source>
        <translation>מספר משבצת שגוי: %1</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>Error loading tileset image:
&apos;%1&apos;</source>
        <translation>בעיה בטעינת תמונת סט המשבצות: &apos;%1&apos;</translation>
    </message>
    <message>
        <location line="+64"/>
        <source>Too many &lt;tile&gt; elements</source>
        <translation>יותר מדי  אלמנטים ל&lt;tile&gt;</translation>
    </message>
    <message>
        <location line="+11"/>
        <location line="+72"/>
        <location line="+39"/>
        <location line="+90"/>
        <source>Invalid tile: %1</source>
        <translation>משבצת שגויה: %1</translation>
    </message>
    <message>
        <location line="-181"/>
        <source>Unknown encoding: %1</source>
        <translation>קידוד לא ידועה: %1</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Compression method &apos;%1&apos; not supported</source>
        <translation>שיטת דחיסה &apos;%1&apos; אינה נתמכת</translation>
    </message>
    <message>
        <location line="+6"/>
        <location line="+39"/>
        <source>Corrupt layer data for layer &apos;%1&apos;</source>
        <translation>מידע פגום לשכבה &apos;%1&apos;</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Unable to parse tile at (%1,%2) on layer &apos;%3&apos;</source>
        <translation>לא היה ניתן לקרוא את המשבצת ב (%1, %2) בשכבה &apos;%3&apos;</translation>
    </message>
    <message>
        <source>Invalid global tile id (less than 0): %1</source>
        <translation type="obsolete">מספר משבצת גלובאלי שגוי (פחות מ-0): %1</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Tile used but no tilesets specified</source>
        <translation>משבצת בשימוש אף על פי שלא צוין סט משבצות</translation>
    </message>
    <message>
        <location filename="../src/libtiled/mapwriter.cpp" line="+101"/>
        <source>Could not open file for writing.</source>
        <translation>לא היה ניתן לפתוח את הקובץ לקריאה.</translation>
    </message>
</context>
<context>
    <name>NewImageLayerDialog</name>
    <message>
        <location filename="../src/tiled/newimagelayerdialog.ui" line="+14"/>
        <source>New Tileset</source>
        <translation>סט משבצות חדש</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Image layer</source>
        <translation>שכבת תמונה</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Name:</source>
        <translation>&amp;שם:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Image:</source>
        <translation>תמונה:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Browse...</source>
        <translation>&amp;סייר...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Use transparent color:</source>
        <translation>השתמש בצבע שקוף:</translation>
    </message>
</context>
<context>
    <name>NewMapDialog</name>
    <message>
        <location filename="../src/tiled/newmapdialog.ui" line="+14"/>
        <source>New Map</source>
        <translation>מפה חדשה</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Map size</source>
        <translation>גודל המפה</translation>
    </message>
    <message>
        <location line="+6"/>
        <location line="+55"/>
        <source>Width:</source>
        <translation>רוחב:</translation>
    </message>
    <message>
        <location line="-32"/>
        <location line="+55"/>
        <source>Height:</source>
        <translation>גובה:</translation>
    </message>
    <message>
        <location line="-29"/>
        <source>Tile size</source>
        <translation>גודל משבצת</translation>
    </message>
    <message>
        <location line="+78"/>
        <source>Map</source>
        <translation>מפה</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Orientation:</source>
        <translation>אורייאנטציה (הטייה):</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Orthogonal</source>
        <translation>אורטוגונלי (ריבועי)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Isometric</source>
        <translation>איסומטרי (אלכסוני)</translation>
    </message>
</context>
<context>
    <name>NewTilesetDialog</name>
    <message>
        <location filename="../src/tiled/newtilesetdialog.ui" line="+6"/>
        <source>New Tileset</source>
        <translation>סט משבצות חדש</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Tileset</source>
        <translation>סט משבצות</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Name:</source>
        <translation>&amp;שם:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Image:</source>
        <translation>תמונה:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Browse...</source>
        <translation>&amp;עיין...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Use transparent color:</source>
        <translation>השתמש בצבע שקוף:</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Tiles</source>
        <translation>משבצות</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Tile width:</source>
        <translation>רוחב משבצת:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Margin:</source>
        <translation>מסגרת:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Tile height:</source>
        <translation>גובה משבצת:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Spacing:</source>
        <translation>ריווח:</translation>
    </message>
</context>
<context>
    <name>ObjectPropertiesDialog</name>
    <message>
        <location filename="../src/tiled/objectpropertiesdialog.ui" line="+26"/>
        <source>Form</source>
        <translation>טופס</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Name:</source>
        <translation>שם:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Type:</source>
        <translation>סוג:</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Position</source>
        <translation>מיקום</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>X:</source>
        <translation></translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Y:</source>
        <translation></translation>
    </message>
    <message>
        <location line="+42"/>
        <source>Size</source>
        <translation>גודל</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Width:</source>
        <translation>רוחב:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Height:</source>
        <translation>גובה:</translation>
    </message>
</context>
<context>
    <name>OffsetMapDialog</name>
    <message>
        <location filename="../src/tiled/offsetmapdialog.ui" line="+17"/>
        <source>Offset Map</source>
        <translation>שנה את גבולות המפה</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Offset Contents of Map</source>
        <translation>שנה את גבולות תכני המפה</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>X:</source>
        <translation></translation>
    </message>
    <message>
        <location line="+23"/>
        <location line="+43"/>
        <source>Wrap</source>
        <translation>עטוף</translation>
    </message>
    <message>
        <location line="-36"/>
        <source>Y:</source>
        <translation></translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Layers:</source>
        <translation>שכבות:</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>All Visible Layers</source>
        <translation>כל השכבות הנראות</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>All Layers</source>
        <translation>כל השכבות</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Selected Layer</source>
        <translation>השכבה הנבחרת</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Bounds:</source>
        <translation>גבולות:</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Whole Map</source>
        <translation>כל המפה</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Current Selection</source>
        <translation>הבחירה הנוכחית</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../src/tiled/preferencesdialog.ui" line="+14"/>
        <source>Preferences</source>
        <translation>העדפות</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Saving and Loading</source>
        <translation>שמירה וטעינה</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Store tile layer data as:</source>
        <translation>&amp;אחסן את מידע שכבת המשבצות בתור:</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>XML</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Base64 (uncompressed)</source>
        <translation>Base64 (ללא דחיסה)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Base64 (gzip compressed)</source>
        <translation>Base64 (דחיסת gzip)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Base64 (zlib compressed)</source>
        <translation>Base64 (דחיסת zlib)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>CSV</source>
        <translation>ערכים מופרדים בפסיק (&apos;,&apos;)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Reload tileset images when they change</source>
        <translation>&amp;טען סט משבצות בעת שינוי</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Not enabled by default since a reference to an external DTD is known to cause problems with some XML parsers.</source>
        <translation>לא מאופשר בדרך כלל מאחר וייחוס חיצוני לDTD ידוע כגורם לבעיות עם חלק מקוראי הXML.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Include &amp;DTD reference in saved maps</source>
        <translation>כלול ייחוס ל&amp;DTD במפות שמורות</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Interface</source>
        <translation>ממשק</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Language:</source>
        <translation>&amp;שפה:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Hardware &amp;accelerated drawing (OpenGL)</source>
        <translation>ציור  עם האצת &amp;חומרה (OpenGL)</translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="../src/tiled/propertiesdialog.ui" line="+14"/>
        <source>Properties</source>
        <translation>ערכים</translation>
    </message>
</context>
<context>
    <name>ResizeDialog</name>
    <message>
        <location filename="../src/tiled/resizedialog.ui" line="+14"/>
        <source>Resize</source>
        <translation>שינוי גודל</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Size</source>
        <translation>גודל</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Width:</source>
        <translation>רוחב:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Height:</source>
        <translation>גובה:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Offset</source>
        <translation>התחלה</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>X:</source>
        <translation></translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Y:</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>SaveAsImageDialog</name>
    <message>
        <location filename="../src/tiled/saveasimagedialog.ui" line="+14"/>
        <source>Save As Image</source>
        <translation>שמור בתור תמונה</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Location</source>
        <translation>מיקום</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Name:</source>
        <translation>שם:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;Browse...</source>
        <translation>&amp;עיון...</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Settings</source>
        <translation>הגדרות</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Only include &amp;visible layers</source>
        <translation>כלול רק שכבות &amp;נראות</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Use current &amp;zoom level</source>
        <translation>השתמשת ברמת הה&amp;גדלה הנוכחית</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Draw tile grid</source>
        <translation>&amp;צייר לוח משבצת</translation>
    </message>
</context>
<context>
    <name>Tengine::TenginePlugin</name>
    <message>
        <location filename="../src/plugins/tengine/tengineplugin.cpp" line="+50"/>
        <source>Could not open file for writing.</source>
        <translation>לא היה ניתן לפתוח את הקובץ לקריאה.</translation>
    </message>
    <message>
        <location line="+243"/>
        <source>T-Engine4 map files (*.lua)</source>
        <translation>קבצי מפה של T-Engine4 (*.lua(</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::AbstractObjectTool</name>
    <message numerus="yes">
        <location filename="../src/tiled/abstractobjecttool.cpp" line="+134"/>
        <location line="+54"/>
        <source>Duplicate %n Object(s)</source>
        <translation>
            <numerusform>שכפל עצם</numerusform>
            <numerusform>שכפל %n עצמים</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="-53"/>
        <location line="+71"/>
        <source>Remove %n Object(s)</source>
        <translation>
            <numerusform>מחק עצם</numerusform>
            <numerusform>מחק %n עצמים</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="-62"/>
        <location line="+72"/>
        <source>Move %n Object(s) to Layer</source>
        <translation>
            <numerusform>הזז עצם לשכבה</numerusform>
            <numerusform>הזז %n עצמים לשכבה</numerusform>
        </translation>
    </message>
    <message>
        <location line="-62"/>
        <source>Object &amp;Properties...</source>
        <translation>&amp;ערכי העצם...</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::AutoMapper</name>
    <message>
        <location filename="../src/tiled/automap.cpp" line="+116"/>
        <source>Multiple layers %1 found!</source>
        <translation>מספר שכבות %1 נמצאו!</translation>
    </message>
    <message>
        <location line="+110"/>
        <source>No ruleRegions layer found!</source>
        <translation>לא נמצאו חוקי אזור שכבה!</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>No set layers found!</source>
        <translation>לא נמצאו מקורות שכבות!</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>No ruleSet layer found!</source>
        <translation>לא נמצאה שכבת סט חוקים!</translation>
    </message>
    <message>
        <location line="+212"/>
        <source>Tile</source>
        <translation>משבצת</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::AutomaticMappingManager</name>
    <message>
        <location line="+497"/>
        <source>No set layer found!</source>
        <translation>לא נמצא מקור שכבה!</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Apply AutoMap rules</source>
        <translation>קבע חוקי מיפוי אוטומתי</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>No rules file found at:
%1</source>
        <translation>לא נמצאו חוקים ב:
%1</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Error opening rules file:
%1</source>
        <translation>בעיה בפתיחת קובץ חוקים:
%1</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>File not found:
%1</source>
        <translation>קובץ לא נמצא:
%1</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Opening rules map failed:
%1</source>
        <translation>פתיחת מפת חוקים נכשלה:
%1</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::BucketFillTool</name>
    <message>
        <location filename="../src/tiled/bucketfilltool.cpp" line="+39"/>
        <location line="+133"/>
        <source>Bucket Fill Tool</source>
        <translation>דלי מילוי</translation>
    </message>
    <message>
        <location line="-130"/>
        <location line="+131"/>
        <source>F</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::CommandButton</name>
    <message>
        <location filename="../src/tiled/commandbutton.cpp" line="+39"/>
        <source>Execute Command</source>
        <translation>בצע פקודה</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>F5</source>
        <translation></translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Error Executing Command</source>
        <translation>בעיה בביצוע פקודה</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>You do not have any commands setup.</source>
        <translation>אין לך תסדיר פקודות.</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Edit commands...</source>
        <translation>ערוך פקודות...</translation>
    </message>
    <message>
        <location line="+45"/>
        <source>Edit Commands...</source>
        <translation>ערוך פקודות...</translation>
    </message>
    <message>
        <source>There was an error running the command</source>
        <translation type="obsolete">הייתה בעיה בהרצת הפקודה</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::CommandDataModel</name>
    <message>
        <location filename="../src/tiled/commanddatamodel.cpp" line="+60"/>
        <source>Open in text editor</source>
        <translation>פתח בעורך טקסט</translation>
    </message>
    <message>
        <location line="+92"/>
        <location line="+67"/>
        <source>&lt;new command&gt;</source>
        <translation>&lt;פקודה חדשה&gt;</translation>
    </message>
    <message>
        <location line="-59"/>
        <source>Set a name for this command</source>
        <translation>בחר בשם עבור פקודה זו</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Set the shell command to execute</source>
        <translation>בחר את פקודת הshell לביצוע</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Show or hide this command in the command list</source>
        <translation>הצג או החבא את הפקודה הזאת ברשימת הפקודות</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Add a new command</source>
        <translation>הוסף פקודה חדשה</translation>
    </message>
    <message>
        <location line="+101"/>
        <source>Name</source>
        <translation>שם</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Command</source>
        <translation>פקודה</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Enable</source>
        <translation>אפשר</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Move Up</source>
        <translation>הזז למעלה</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Move Down</source>
        <translation>הזז למטה</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Execute</source>
        <translation>בצע</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Execute in Terminal</source>
        <translation>בצע בטרמינל</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Delete</source>
        <translation>מחק</translation>
    </message>
    <message>
        <location line="+84"/>
        <source>%1 (copy)</source>
        <translation>%1 (העתק)</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>New command</source>
        <translation>פקודה חדשה</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::CommandDialog</name>
    <message>
        <location filename="../src/tiled/commanddialog.cpp" line="+40"/>
        <source>Edit Commands</source>
        <translation>ערוך פקודות</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::CommandProcess</name>
    <message>
        <location filename="../src/tiled/command.cpp" line="+122"/>
        <source>Unable to create/open %1</source>
        <translation>לא ניתן ליצור/לפתוח %1</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Unable to add executable permissions to %1</source>
        <translation>לא ניתן להוסיף גישות יישום ל%1</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>The command failed to start.</source>
        <translation>כישלון בהפעלת הפקודה.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>The command crashed.</source>
        <translation>הפקודה קרסה.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>The command timed out.</source>
        <translation>חלף הזמן שניתן לפקודה להתצבע.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>An unknown error occurred.</source>
        <translation>התרחשה שגיאה לא ידועה.</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Error Executing %1</source>
        <translation>שגיאה בביצוע %1</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::CreateObjectTool</name>
    <message>
        <source>Create Objects</source>
        <translation type="obsolete">צור עצמים</translation>
    </message>
    <message>
        <location filename="../src/tiled/createobjecttool.cpp" line="+42"/>
        <location line="+100"/>
        <source>O</source>
        <translation></translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Insert Objects</source>
        <translation>הכנסת עצמים</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Insert Tile Objects</source>
        <translation>הכנסת עצמי משבצות</translation>
    </message>
    <message>
        <source>Create Tile Objects</source>
        <translation type="obsolete">צור עצמיי משבצות</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>T</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::Eraser</name>
    <message>
        <location filename="../src/tiled/eraser.cpp" line="+34"/>
        <location line="+36"/>
        <source>Eraser</source>
        <translation>מחק</translation>
    </message>
    <message>
        <location line="-33"/>
        <location line="+34"/>
        <source>E</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::ImageLayerPropertiesDialog</name>
    <message>
        <location filename="../src/tiled/imagelayerpropertiesdialog.cpp" line="+60"/>
        <source>Image Layer</source>
        <translation>שכבת תמונה</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Browse...</source>
        <translation>סייר...</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Image:</source>
        <translation>תמונה:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Transparent color:</source>
        <translation>צבע שקוף:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Layer Image</source>
        <translation>תמונת שכבה</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::LayerDock</name>
    <message>
        <location filename="../src/tiled/layerdock.cpp" line="+179"/>
        <source>Layers</source>
        <translation>שכבות</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Opacity:</source>
        <translation>שקיפות:</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::LayerModel</name>
    <message>
        <location filename="../src/tiled/layermodel.cpp" line="+122"/>
        <source>Layer</source>
        <translation>שכבה</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::MainWindow</name>
    <message>
        <location filename="../src/tiled/mainwindow.cpp" line="+134"/>
        <location line="+8"/>
        <source>Undo</source>
        <translation>בטל</translation>
    </message>
    <message>
        <location line="-7"/>
        <location line="+6"/>
        <source>Redo</source>
        <translation>החזר</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Ctrl+=</source>
        <translation></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>+</source>
        <translation></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>-</source>
        <translation></translation>
    </message>
    <message>
        <location line="+22"/>
        <location line="+1047"/>
        <source>&amp;Layer</source>
        <translation>&amp;שכבה</translation>
    </message>
    <message>
        <location line="-910"/>
        <source>Ctrl+PgUp</source>
        <translation></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Ctrl+PgDown</source>
        <translation></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>X</source>
        <translation></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Y</source>
        <translation></translation>
    </message>
    <message>
        <location line="+127"/>
        <source>Error Opening Map</source>
        <translation>בעיה בפתיחת המפה</translation>
    </message>
    <message>
        <location line="+73"/>
        <location line="+135"/>
        <source>All Files (*)</source>
        <translation>כל הקבצים (*)</translation>
    </message>
    <message>
        <location line="-132"/>
        <location line="+76"/>
        <source>Tiled map files (*.tmx)</source>
        <translation>כל קבצי Tiled (*.tmx)</translation>
    </message>
    <message>
        <location line="-63"/>
        <source>Open Map</source>
        <translation>פתח מפה</translation>
    </message>
    <message>
        <location line="+25"/>
        <location line="+141"/>
        <source>Error Saving Map</source>
        <translation>בעיה בשמירת מפה</translation>
    </message>
    <message>
        <location line="-108"/>
        <source>untitled.tmx</source>
        <translation>ללא_שם.tmx</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Unsaved Changes</source>
        <translation>לא נשמרו שינויים</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>There are unsaved changes. Do you want to save now?</source>
        <translation>אלו הם שינויים שלא נשמרו. ברצונך לשמורם כעת?</translation>
    </message>
    <message>
        <location line="+52"/>
        <source>Export As...</source>
        <translation>יצא בתור...</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Unknown File Format</source>
        <translation>פורמט קובץ לא ידוע</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The given filename does not have any known file extension.</source>
        <translation>שם הקובץ הנתון אינו כולל סיומת ידועה.</translation>
    </message>
    <message>
        <location line="+41"/>
        <source>Cut</source>
        <translation>גזור</translation>
    </message>
    <message>
        <location line="+80"/>
        <source>Paste Objects</source>
        <translation>הדבק עצמים</translation>
    </message>
    <message>
        <location line="+79"/>
        <source>Add External Tileset</source>
        <translation>הוסף סט משבצות חיצוני</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Tiled tileset files (*.tsx)</source>
        <translation>קבצי סט משבצות של Tiled (*.tsx)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Error Reading Tileset</source>
        <translation>בעיה בקריאת סט משבצות</translation>
    </message>
    <message>
        <location line="+46"/>
        <source>Map</source>
        <translation>מפה</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Automatic Mapping</source>
        <translation>מיפוי אוטומתי</translation>
    </message>
    <message>
        <location line="+223"/>
        <source>[*]%1 - Tiled</source>
        <translation></translation>
    </message>
    <message>
        <source>Apply AutoMap rules</source>
        <translation type="obsolete">קבע חוקי מיפוי אוטומתי</translation>
    </message>
    <message>
        <location line="-103"/>
        <source>%1%</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::MapDocument</name>
    <message>
        <location filename="../src/tiled/mapdocument.cpp" line="+133"/>
        <source>untitled.tmx</source>
        <translation>ללא_שם.tmx</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>Resize Map</source>
        <translation>שנה גודל מפה</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Offset Map</source>
        <translation>שנה גבולות מפה</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Tile Layer %1</source>
        <translation>שכבת משבצות %1</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Object Layer %1</source>
        <translation>שכבת עצמים %1</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Copy of %1</source>
        <translation>העתק של %1</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Duplicate Layer</source>
        <translation>שכפל שכבה</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Merge Layer Down</source>
        <translation>מזג עם שכבה למטה</translation>
    </message>
    <message>
        <location line="+138"/>
        <source>Tile</source>
        <translation>משבצת</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Tileset Changes</source>
        <translation>שינויים בסט משבצות</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::MapDocumentActionHandler</name>
    <message>
        <location filename="../src/tiled/mapdocumentactionhandler.cpp" line="+46"/>
        <source>Ctrl+Shift+A</source>
        <translation></translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Ctrl+Shift+D</source>
        <translation></translation>
    </message>
    <message>
        <location line="+11"/>
        <source>PgUp</source>
        <translation></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>PgDown</source>
        <translation></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+Shift+Up</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Ctrl+Shift+Down</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Ctrl+Shift+H</source>
        <translation></translation>
    </message>
    <message>
        <location line="+45"/>
        <source>Select &amp;All</source>
        <translation>בחר &amp;הכל</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Select &amp;None</source>
        <translation>בחר &amp;שום דבר</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>&amp;Crop to Selection</source>
        <translation>&amp;חתוך לבחירה</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Add &amp;Tile Layer</source>
        <translation>הוסף שכבת מ&amp;שבצות</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Add &amp;Object Layer</source>
        <translation>הוסף שכבת &amp;עצמים</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Select Pre&amp;vious Layer</source>
        <translation>בחר שכבה &amp;קודמת</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Select &amp;Next Layer</source>
        <translation>בחר שכבה אח&amp;רי</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>R&amp;aise Layer</source>
        <translation>ה&amp;עלה שכבה</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&amp;Lower Layer</source>
        <translation>הנמ&amp;ך שכבה</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Show/&amp;Hide all Other Layers</source>
        <translation>ה&amp;צג/החבא את השכבות האחרות</translation>
    </message>
    <message>
        <source>Add &amp;Tile Layer...</source>
        <translation type="obsolete">הוסף שכבת מ&amp;שבצות...</translation>
    </message>
    <message>
        <source>Add &amp;Object Layer...</source>
        <translation type="obsolete">הוסף שכבת &amp;עצמים...</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>&amp;Duplicate Layer</source>
        <translation>ש&amp;כפל שכבה</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&amp;Merge Layer Down</source>
        <translation>מ&amp;זג שכבה למטה</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&amp;Remove Layer</source>
        <translation>&amp;מחק שכבה</translation>
    </message>
    <message>
        <source>Move Layer &amp;Up</source>
        <translation type="obsolete">הזז שכבה למע&amp;לה</translation>
    </message>
    <message>
        <source>Move Layer Dow&amp;n</source>
        <translation type="obsolete">הזז שכבה למ&amp;טה</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Layer &amp;Properties...</source>
        <translation>ע&amp;רכי שכבה...</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::NewMapDialog</name>
    <message>
        <location filename="../src/tiled/newmapdialog.cpp" line="+81"/>
        <source>Tile Layer 1</source>
        <translation>שכבת משבצות 1</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::NewTilesetDialog</name>
    <message>
        <location filename="../src/tiled/newtilesetdialog.cpp" line="+123"/>
        <location line="+7"/>
        <source>Error</source>
        <translation>שגיאה</translation>
    </message>
    <message>
        <location line="-6"/>
        <source>Failed to load tileset image &apos;%1&apos;.</source>
        <translation>כשלון בעת תמונת סט המשבצות: &apos;%1&apos;.</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>No tiles found in the tileset image when using the given tile size, margin and spacing!</source>
        <translation>לא נמצאו משבצות לתמונת סט המשבצות עם הגודל, מסגרת או הריווח הנתונים!</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Tileset Image</source>
        <translation>תמונת סט משבצות</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::ObjectGroupPropertiesDialog</name>
    <message>
        <location filename="../src/tiled/objectgrouppropertiesdialog.cpp" line="+43"/>
        <source>Object Layer</source>
        <translation>שכבת עצמים</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Color:</source>
        <translation>צבע:</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::ObjectPropertiesDialog</name>
    <message>
        <location filename="../src/tiled/objectpropertiesdialog.cpp" line="+41"/>
        <source>Object</source>
        <translation>עצם</translation>
    </message>
    <message>
        <location line="+52"/>
        <source>Change Object</source>
        <translation>שנה עצם</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::ObjectSelectionTool</name>
    <message>
        <location filename="../src/tiled/objectselectiontool.cpp" line="+98"/>
        <location line="+110"/>
        <source>Select Objects</source>
        <translation>בחירת עצמים</translation>
    </message>
    <message>
        <location line="-108"/>
        <location line="+109"/>
        <source>S</source>
        <translation></translation>
    </message>
    <message>
        <source>Object &amp;Properties...</source>
        <translation type="obsolete">&amp;ערכי העצם...</translation>
    </message>
    <message numerus="yes">
        <source>Duplicate %n Object(s)</source>
        <translation type="obsolete">
            <numerusform>שכפל %n עצמ(ים)</numerusform>
            <numerusform>שכפל %n עצמים</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Remove %n Object(s)</source>
        <translation type="obsolete">
            <numerusform>מחק עצמים</numerusform>
            <numerusform>Remove %n Objects</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Move %n Object(s) to Layer</source>
        <translation type="obsolete">
            <numerusform>הזז עצם לשכבה</numerusform>
            <numerusform>הזז %n עצמים לשכבה</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+117"/>
        <source>Move %n Object(s)</source>
        <translation>
            <numerusform>הזז עצם</numerusform>
            <numerusform>הזז %n עצמים</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::PreferencesDialog</name>
    <message>
        <location filename="../src/tiled/preferencesdialog.cpp" line="+56"/>
        <location line="+23"/>
        <source>System default</source>
        <translation>ברירת מחדל של המערכת</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::PropertiesDialog</name>
    <message>
        <location filename="../src/tiled/propertiesdialog.cpp" line="+69"/>
        <source>%1 Properties</source>
        <translation>%1 ערכים</translation>
    </message>
    <message>
        <location line="+37"/>
        <source>Layer</source>
        <translation>שכבה</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::PropertiesModel</name>
    <message>
        <location filename="../src/tiled/propertiesmodel.cpp" line="+51"/>
        <source>&lt;new property&gt;</source>
        <translation>&lt;ערך חדש&gt;</translation>
    </message>
    <message>
        <location line="+68"/>
        <source>Name</source>
        <translation>שם</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Value</source>
        <translation>ערך</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::SaveAsImageDialog</name>
    <message>
        <location filename="../src/tiled/saveasimagedialog.cpp" line="+111"/>
        <source>Save as Image</source>
        <translation>שמור בתור תמונה</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 כבר קיים.
ברצונך להחליפו?</translation>
    </message>
    <message>
        <location line="+73"/>
        <source>Image</source>
        <translation>תמונה</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::SelectionTool</name>
    <message>
        <location filename="../src/tiled/selectiontool.cpp" line="+34"/>
        <location line="+81"/>
        <source>Rectangular Select</source>
        <translation>בחירה מלבנית</translation>
    </message>
    <message>
        <location line="-78"/>
        <location line="+79"/>
        <source>R</source>
        <translation></translation>
    </message>
    <message>
        <location line="-56"/>
        <source>%1, %2 - Rectangle: (%3 x %4)</source>
        <translation>%1, %2 - מלבן: (%3 x %4)</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::StampBrush</name>
    <message>
        <location filename="../src/tiled/stampbrush.cpp" line="+38"/>
        <location line="+281"/>
        <source>Stamp Brush</source>
        <translation>בחירת מברשת</translation>
    </message>
    <message>
        <location line="-278"/>
        <location line="+279"/>
        <source>B</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::TilesetDock</name>
    <message>
        <location filename="../src/tiled/tilesetdock.cpp" line="+279"/>
        <source>Remove Tileset</source>
        <translation>מחק סט משבצות</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The tileset &quot;%1&quot; is still in use by the map!</source>
        <translation>סט המשבצות &quot;%1&quot; עדיין בשימוש על-ידי המפה!</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Remove this tileset and all references to the tiles in this tileset?</source>
        <translation>מחק את סט המשבצות הזה וכל הייחוסים למשבצות שלו?</translation>
    </message>
    <message>
        <location line="+64"/>
        <source>Tilesets</source>
        <translation>סטי משבצות</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::TilesetView</name>
    <message>
        <location filename="../src/tiled/tilesetview.cpp" line="+213"/>
        <source>Tile &amp;Properties...</source>
        <translation>&amp;ערכי משבצת...</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;Export Tileset As...</source>
        <translation>&amp;יצא סט משבצות בתור...</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&amp;Import Tileset</source>
        <translation>&amp;ייבא סט משבצות</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Show &amp;Grid</source>
        <translation>הצג &amp;לוח</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Tile</source>
        <translation>משבצת</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Export Tileset</source>
        <translation>ייצא סט משבצות</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Tiled tileset files (*.tsx)</source>
        <translation>קובץ סט משבצות של Tiled (*.tsx(</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::ToolManager</name>
    <message>
        <location filename="../src/tiled/toolmanager.cpp" line="+88"/>
        <source>Tools</source>
        <translation>כלים</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::UndoDock</name>
    <message>
        <location filename="../src/tiled/undodock.cpp" line="+64"/>
        <source>History</source>
        <translation>היסטורייה</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&lt;empty&gt;</source>
        <translation>&lt;ריק&gt;</translation>
    </message>
</context>
<context>
    <name>Tmw::TmwPlugin</name>
    <message>
        <location filename="../src/plugins/tmw/tmwplugin.cpp" line="+47"/>
        <source>Multiple collision layers found!</source>
        <translation>מספר קבצי שכבות התנגשות נמצאו!</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>No collision layer found!</source>
        <translation>לא נמצאה שכבת התנגשות!</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Could not open file for writing.</source>
        <translation>לא ניתן היה לפתוח את הקובץ לכתיבה.</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>TMW-eAthena collision files (*.wlk)</source>
        <translation>קבצי התנגשות של TMW-eAthena (*.wlk)</translation>
    </message>
</context>
<context>
    <name>TmxMapReader</name>
    <message>
        <location filename="../src/tiled/tmxmapreader.h" line="+55"/>
        <location filename="../src/tiled/tmxmapwriter.h" line="+56"/>
        <source>Tiled map files (*.tmx)</source>
        <translation>קבצי משבצות של Tiled (*.tmx(</translation>
    </message>
</context>
<context>
    <name>TmxViewer</name>
    <message>
        <location filename="../src/tmxviewer/tmxviewer.cpp" line="+160"/>
        <source>TMX Viewer</source>
        <translation>מראה קבצי TMX</translation>
    </message>
</context>
<context>
    <name>Undo Commands</name>
    <message>
        <location filename="../src/tiled/addremovelayer.h" line="+67"/>
        <source>Add Layer</source>
        <translation>הוספת שכבה</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Remove Layer</source>
        <translation>מחיקת שכבה</translation>
    </message>
    <message>
        <location filename="../src/tiled/addremovemapobject.cpp" line="+79"/>
        <source>Add Object</source>
        <translation>הוספת עצם</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Remove Object</source>
        <translation>מחיקת עצם</translation>
    </message>
    <message>
        <location filename="../src/tiled/addremovetileset.cpp" line="+62"/>
        <source>Add Tileset</source>
        <translation>הוספת סט משבצות</translation>
    </message>
    <message>
        <location filename="../src/tiled/addremovetileset.h" line="+78"/>
        <source>Remove Tileset</source>
        <translation>מחיקת סט משבצות</translation>
    </message>
    <message>
        <location filename="../src/tiled/changemapobject.cpp" line="+35"/>
        <source>Change Object</source>
        <translation>שינוי עצם</translation>
    </message>
    <message>
        <location filename="../src/tiled/changeobjectgroupproperties.cpp" line="+37"/>
        <location filename="../src/tiled/objectgrouppropertiesdialog.cpp" line="+21"/>
        <source>Change Object Layer Properties</source>
        <translation>שינוי ערכי שכבת עצמים</translation>
    </message>
    <message>
        <location filename="../src/tiled/changeproperties.cpp" line="+34"/>
        <source>Change %1 Properties</source>
        <translation>שינוי %1 ערכים</translation>
    </message>
    <message>
        <location filename="../src/tiled/changetileselection.cpp" line="+31"/>
        <source>Change Selection</source>
        <translation>שינוי בחירה</translation>
    </message>
    <message>
        <location filename="../src/tiled/erasetiles.cpp" line="+39"/>
        <source>Erase</source>
        <translation>מחיקה</translation>
    </message>
    <message>
        <location filename="../src/tiled/filltiles.cpp" line="+36"/>
        <source>Fill Area</source>
        <translation>מילוי שטח</translation>
    </message>
    <message>
        <source>Move Layer Down</source>
        <translation type="obsolete">הזזת שכבה למטה</translation>
    </message>
    <message>
        <source>Move Layer Up</source>
        <translation type="obsolete">הזזת שכבה למעלה</translation>
    </message>
    <message>
        <location filename="../src/tiled/movemapobject.cpp" line="+39"/>
        <source>Move Object</source>
        <translation>הזזת עצם</translation>
    </message>
    <message>
        <location filename="../src/tiled/movemapobjecttogroup.cpp" line="+40"/>
        <source>Move Object to Layer</source>
        <translation>הזזת עצם לשכבה</translation>
    </message>
    <message>
        <location filename="../src/tiled/movetileset.cpp" line="+31"/>
        <source>Move Tileset</source>
        <translation>הוזזת סט משבצות</translation>
    </message>
    <message>
        <location filename="../src/tiled/offsetlayer.cpp" line="+40"/>
        <source>Offset Layer</source>
        <translation>שינוי תחומי שכבה</translation>
    </message>
    <message>
        <location filename="../src/tiled/painttilelayer.cpp" line="+49"/>
        <source>Paint</source>
        <translation>ציור</translation>
    </message>
    <message>
        <location filename="../src/tiled/renamelayer.cpp" line="+40"/>
        <source>Rename Layer</source>
        <translation>שינוי שם שכבה</translation>
    </message>
    <message>
        <location filename="../src/tiled/resizelayer.cpp" line="+37"/>
        <source>Resize Layer</source>
        <translation>שינוי גודל שכבה</translation>
    </message>
    <message>
        <location filename="../src/tiled/resizemap.cpp" line="+32"/>
        <source>Resize Map</source>
        <translation>שינוי גודל מפה</translation>
    </message>
    <message>
        <location filename="../src/tiled/resizemapobject.cpp" line="+39"/>
        <source>Resize Object</source>
        <translation>שינוי גודל עצם</translation>
    </message>
    <message>
        <location filename="../src/tiled/tilesetview.cpp" line="-159"/>
        <source>Import Tileset</source>
        <translation>ייבוא סט משבצות</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Export Tileset</source>
        <translation>ייצוא סט משבצות</translation>
    </message>
    <message>
        <location filename="../src/tiled/changeimagelayerproperties.cpp" line="+39"/>
        <location filename="../src/tiled/imagelayerpropertiesdialog.cpp" line="+28"/>
        <source>Change Image Layer Properties</source>
        <translation>שנה מאפייני שכבת תמונה</translation>
    </message>
    <message>
        <location filename="../src/tiled/movelayer.cpp" line="+37"/>
        <source>Lower Layer</source>
        <translation>הנמך שכבה</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Raise Layer</source>
        <translation>העלה שכבה</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <location filename="../src/tiled/utils.cpp" line="+31"/>
        <source>Image files</source>
        <translation>קבצי תמונה</translation>
    </message>
</context>
</TS>
